@@ -29,27 +29,22 @@
 
 #include <hex-document.h>
 
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 /* how to group bytes? */
 #define GROUP_BYTE 1
 #define GROUP_WORD 2
 #define GROUP_LONG 4
 
-#define VIEW_HEX 1
-#define VIEW_ASCII 2
-
 #define LOWER_NIBBLE TRUE
 #define UPPER_NIBBLE FALSE
 
-#define DEFAULT_FONT "Courier Medium 12"
-
-#define GTK_HEX(obj)          GTK_CHECK_CAST (obj, gtk_hex_get_type (), GtkHex)
-#define GTK_HEX_CLASS(klass)  GTK_CHECK_CLASS_CAST (klass, gtk_hex_get_type (), GtkHexClass)
-#define GTK_IS_HEX(obj)       GTK_CHECK_TYPE (obj, gtk_hex_get_type ())
+#define GTK_TYPE_HEX                    (gtk_hex_get_type ())
+#define GTK_HEX(obj)                    (G_TYPE_CHECK_INSTANCE_CAST ((obj), GTK_TYPE_HEX, GtkHex))
+#define GTK_HEX_CLASS(klass)            (G_TYPE_CHECK_CLASS_CAST ((klass), GTK_TYPE_HEX, GtkHexClass))
+#define GTK_IS_HEX(obj)                 (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GTK_TYPE_HEX))
+#define GTK_IS_HEX_CLASS(klass)         (G_TYPE_CHECK_CLASS_TYPE ((klass), GTK_TYPE_HEX))
+#define GTK_HEX_GET_CLASS(obj)          (G_TYPE_INSTANCE_GET_CLASS ((obj), GTK_TYPE_HEX, GtkHexClass))
 
 typedef struct _GtkHex GtkHex;
 typedef struct _GtkHexClass GtkHexClass;
@@ -91,8 +86,6 @@ struct _GtkHex
 	PangoFontMetrics *disp_font_metrics;
 	PangoFontDescription *font_desc;
 
-	GdkGC *xdisp_gc, *adisp_gc, *offsets_gc;
-	
 	gint active_view;
 	
 	guint char_width, char_height;
@@ -118,6 +111,7 @@ struct _GtkHex
 	gint scroll_dir;
 	guint scroll_timeout;
 	gboolean show_offsets;
+	gint starting_offset;
 	gboolean insert;
 	gboolean selecting;
 };
@@ -135,7 +129,7 @@ struct _GtkHexClass
 	void (*paste_clipboard)(GtkHex *);
 };
 
-guint gtk_hex_get_type(void);
+GType           gtk_hex_get_type                (void) G_GNUC_CONST;
 
 GtkWidget *gtk_hex_new(HexDocument *);
 
@@ -148,28 +142,34 @@ guchar gtk_hex_get_byte(GtkHex *, guint);
 
 void gtk_hex_set_group_type(GtkHex *, guint);
 
+void gtk_hex_set_starting_offset(GtkHex *, gint);
 void gtk_hex_show_offsets(GtkHex *, gboolean);
-void gtk_hex_set_font(GtkHex *, PangoFontMetrics *, PangoFontDescription *);
+void gtk_hex_set_font(GtkHex *, PangoFontMetrics *, const PangoFontDescription *);
 
 void gtk_hex_set_insert_mode(GtkHex *, gboolean);
 
+void gtk_hex_set_geometry(GtkHex *gh, gint cpl, gint vis_lines);
+
 PangoFontMetrics* gtk_hex_load_font (const char *font_name); 
 
-void gtk_hex_copy_clipboard(GtkHex *gh);
-void gtk_hex_cut_clipboard(GtkHex *gh);
-void gtk_hex_paste_clipboard(GtkHex *gh);
+void gtk_hex_copy_to_clipboard(GtkHex *gh);
+void gtk_hex_cut_to_clipboard(GtkHex *gh);
+void gtk_hex_paste_from_clipboard(GtkHex *gh);
 
 void add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc);
 void add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType type);
 
+void     gtk_hex_set_selection(GtkHex *gh, gint start, gint end);
+gboolean gtk_hex_get_selection(GtkHex *gh, gint *start, gint *end);
+void     gtk_hex_clear_selection(GtkHex *gh);
+void     gtk_hex_delete_selection(GtkHex *gh);
+
 GtkHex_AutoHighlight *gtk_hex_insert_autohighlight(GtkHex *gh,
 												   const gchar *search,
 												   gint len,
                                                    const gchar *colour);
 void gtk_hex_delete_autohighlight(GtkHex *gh, GtkHex_AutoHighlight *ahl);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif
